==> nudge_leaderboard_ui-0.0.8.tar.gz: lib/features/leaderboard/presentation/widgets/appbar/leaderboard_appbar.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';

class LeaderboardAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Function(int, int)? refreshDataOnDateChanged;

  @override
  Size get preferredSize => const Size.fromHeight(kToolbarHeight);

  LeaderboardAppBar({
    super.key,
    this.refreshDataOnDateChanged,
  });

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: Color.fromRGBO(49, 162, 215, 1),
      actions: [
        refreshDataOnDateChanged != null
            ? IconButton(
                icon:
                    const Icon(Icons.date_range_outlined, color: Colors.white),
                onPressed: () {
                  DateTimeRange? dateRange;

                  Future<void> selectDateRange() async {
                    final DateTimeRange? picked = await showDateRangePicker(
                      initialEntryMode: DatePickerEntryMode.calendar,
                      context: context,
                      firstDate: DateTime(DateTime.now().year - 2),
                      lastDate: DateTime.now(),
                      builder: (BuildContext context, Widget? child) {
                        return Theme(
                          data: ThemeData.light().copyWith(
                            colorScheme: const ColorScheme.dark(
                              primary: Color.fromRGBO(49, 162, 215, 1),
                              onPrimary: Colors.black,
                              surface: Color.fromRGBO(49, 162, 215, 1),
                              onSurface: Color.fromRGBO(49, 162, 215, 1),
                            ),
                            dialogBackgroundColor:
                                const Color.fromRGBO(49, 162, 215, 1),
                          ),
                          child: child!,
                        );
                      },
                    );

                    if (picked != null && picked != dateRange) {
                      dateRange = picked;
                      log('Date range selected: ${dateRange!.start.toIso8601String().split('T')[0]} - ${dateRange!.end.toIso8601String().split('T')[0]}',
                          name: 'leaderboard app bar');
                    }

                    refreshDataOnDateChanged!(
                      dateRange!.start.millisecondsSinceEpoch,
                      dateRange!.end.millisecondsSinceEpoch,
                    );
                  }

                  selectDateRange();
                },
              )
            : const SizedBox(),
      ],
      leading: IconButton(
        icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
        onPressed: () {
          Navigator.of(context).pop();
        },
      ),
      title: const Text(
        'Leaderboard',
        style: TextStyle(
          color: Colors.white,
          fontSize: 16,
          fontWeight: FontWeight.normal,
        ),
      ),
    );
  }
}

==> nudge_leaderboard_ui-0.0.9.tar.gz: lib/features/leaderboard/presentation/widgets/appbar/leaderboard_appbar.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';

class LeaderboardAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Function(int, int)? refreshDataOnDateChanged;

  @override
  Size get preferredSize => const Size.fromHeight(kToolbarHeight);

  const LeaderboardAppBar({
    super.key,
    this.refreshDataOnDateChanged,
  });

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: const Color.fromRGBO(49, 162, 215, 1),
      actions: [
        refreshDataOnDateChanged != null
            ? IconButton(
                icon:
                    const Icon(Icons.date_range_outlined, color: Colors.white),
                onPressed: () {
                  DateTimeRange? dateRange;

                  Future<void> selectDateRange() async {
                    final DateTimeRange? picked = await showDateRangePicker(
                      initialEntryMode: DatePickerEntryMode.calendar,
                      context: context,
                      firstDate: DateTime(DateTime.now().year - 2),
                      lastDate: DateTime.now(),
                      builder: (BuildContext context, Widget? child) {
                        return Theme(
                          data: ThemeData.light().copyWith(
                            colorScheme: const ColorScheme.dark(
                              primary: Color.fromRGBO(49, 162, 215, 1),
                              onPrimary: Colors.black,
                              surface: Color.fromRGBO(49, 162, 215, 1),
                              onSurface: Color.fromRGBO(49, 162, 215, 1),
                            ),
                            dialogBackgroundColor:
                                const Color.fromRGBO(49, 162, 215, 1),
                          ),
                          child: child!,
                        );
                      },
                    );

                    if (picked != null && picked != dateRange) {
                      dateRange = picked;
                      log('Date range selected: ${dateRange!.start.toIso8601String().split('T')[0]} - ${dateRange!.end.toIso8601String().split('T')[0]}',
                          name: 'leaderboard app bar');
                    }

                    refreshDataOnDateChanged!(
                      dateRange!.start.millisecondsSinceEpoch,
                      dateRange!.end.millisecondsSinceEpoch,
                    );
                  }

                  selectDateRange();
                },
              )
            : const SizedBox(),
      ],
      leading: IconButton(
        icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
        onPressed: () {
          Navigator.of(context).pop();
        },
      ),
      title: const Text(
        'Leaderboard',
        style: TextStyle(
          color: Colors.white,
          fontSize: 16,
          fontWeight: FontWeight.normal,
        ),
      ),
    );
  }
}
